import paramiko


class SshCmd(object):
    def __init__(self, hostname, username, password):
        try:
            self.client = paramiko.SSHClient()
            self.client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
            self.client.connect(hostname=hostname, port=22, username=username, password=password)
        except Exception as e:
            raise

    def close(self):
        self.client.close()

    def exec_cmd(self, cmdstr):
        try:
            stdin, stdout, stderr = self.client.exec_command(cmdstr)
            result = stdout.read()
            result = result.decode(encoding='UTF-8', errors='strict')

            errmsg = stderr.read()
            errmsg = errmsg.decode(encoding='UTF-8', errors='strict')

            if errmsg != "":
                raise Exception(errmsg)

            return result

        except Exception as e:
            raise



import setuptools
setuptools.setup(
    name="sshcmd", 
    packages=setuptools.find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    version="0.3",
    license='MIT',
    author="lxl",
    author_email="xliang.lee@qq.com",
    description="ssh cmd",
    long_description="ssh cmd",
    long_description_content_type="text/markdown",
    url="",
    classifiers=[
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
    ],
    keywords=['ssh', 'cmd'],
    python_requires='>=2.6',
    install_requires=[
        'paramiko',
    ],
 )

